function [choiceM,choiceMnoK,LuM,LiM,LiMnoK,VuM,VM,VMnoK,VaM,eta] = fPsimn(Par,nsamp,A,Wsp,Psp,avAadj,avAclose)
%
% Function that uses inferred expe to compare realized l and V under 
% (i) a no fragmentation regime (A is large) and 
% (ii) no cost K regime against the benchmark one. 
%

a    = Par(1);
c    = Par(2);
g    = Par(3);
eta_0  = Par(4);
eta_1 = Par(5);
eta_2 = Par(6);
k_L  = Par(7);
k_T  = Par(8);
b    = Par(9);
is_e = Par(10);

leta = eta_0 + eta_1*log(avAadj) + eta_2*avAclose;
eta = 1./(1+exp(leta));

K_L = k_L + b*log(avAadj);
K_T = k_T + b*log(avAadj);

n = length(A);

v = ones(1,nsamp);
rng(12345);

rH = haltonset(nsamp,'skip',50);
rM = net(rH,n); 
expeM = exp((1/is_e)*norminv(rM));

w0 = (c/(1-a))^(1/a);
delta = ((1-eta*(1-a))./a).*eta.^(1/a-1);

Kg = (1+g)^((a-1)/a);
EWa = sum(Psp.*(Wsp.^a),2);

EW = sum(Psp.*Wsp,2);

Lu = (1/w0)*EWa.^(1/a);
%Lu0 = (1/w0)*EW;

Vu = a*w0^(a-1)*EWa.^(1/a);
%Vu0 = a*w0^(a-1)*EW;

expeMt = expeM.^((a-1)/a);

VuM = (Vu*v).*expeMt;
VsM = VuM.*((Lu*v).*(expeM.^(-1/a))<=A*v);
VaM = (A.^(1-a).*EWa)*v - c*(A*v).*expeM;
VpM = ((delta.*Vu)*v).*expeMt - K_T*v;
VlM = Kg*(Vu*v).*expeMt + (g*c)*(A*v).*expeM - K_L*v;
VlM = VlM.*((1+g)^(-1/a)*(Lu*v).*(expeM.^(-1/a))>A*v);

VpMnoK = ((delta.*Vu)*v).*expeMt;
VcM = zeros(n,nsamp);
VcMnoK = zeros(n,nsamp);

for i=1:n
    iw = find(Psp(i,:)>0,1);
    l0H = Wsp(i,iw)/w0;

    for j = 1:nsamp
        expe = expeM(i,j);
        if expe > 0
            Parl = [a w0 expe l0H A(i) Wsp(i,:) Psp(i,:)];
            f = @(x)C_l2(x,Parl);
            if C_l2(-10,Parl)*C_l2(10,Parl)<0
                x2 = fzero(f,[-10 10]);
            elseif abs(C_l2(-10,Parl)) < abs(C_l2(10,Parl))
                x2 = -10;
            else
                x2 = 10;
            end;
            lC = (exp(x2)/(1+exp(x2)))*(l0H-1e-4)/expe^(1/a);
            VcM(i,j) = A(i).^(1-a).*sum((Psp(i,:).*(Wsp(i,:)-(w0*expe.^(1/a).*lC*ones(1,4))).^a),2) - c*expe.*A(i) + a*w0^a*expe.*lC - K_T(i);
            LcM(i,j) = lC;
            VcMnoK(i,j) = VcM(i,j) + K_T(i);           
        end;              
    end;        
end;

sumP = sum(Psp,2);
ip0 = find(sumP < .98);
VcM(ip0,:) = 0;
VcMnoK(ip0,:) = 0;
LcM(ip0,:) = 0;
LMmax = zeros(n,1);
LMnoK = zeros(n,1);

for i=1:nsamp
    [Vmax, imax]= max([VsM(:,i) VaM(:,i) VlM(:,i) VpM(:,i) VcM(:,i)],[],2); 
    VM(:,i) = Vmax;
    choiceM(:,i) = imax;

    LMmax(find(imax == 1)) = (Lu(find(imax == 1)).*expeM(find(imax == 1),i).^(-1/a));
    LMmax(find(imax == 2)) = A(find(imax == 2));
    LMmax(find(imax == 3)) = (1+g)^(-1/a)*Lu(find(imax == 3)).*expeM(find(imax == 3),i).^(-1/a);
    LMmax(find(imax == 4)) = eta(find(imax == 4)).^(1/a).*Lu(find(imax == 4)).*expeM(find(imax == 4),i).^(-1/a);
    LMmax(find(imax == 5)) = LcM(find(imax == 5),i) + A(find(imax == 5));
    
    LiM(:,i) = LMmax;

        % Counterfactual Regime;
 
    [VnoK, inoK]= max([VsM(:,i) VaM(:,i) VlM(:,i) VpMnoK(:,i) VcMnoK(:,i)],[],2); 
    VMnoK(:,i) = VnoK;
    choiceMnoK(:,i) = inoK;

    LMnoK(find(inoK == 1)) = (Lu(find(inoK == 1)).*expeM(find(inoK == 1),i).^(-1/a));
    LMnoK(find(inoK == 2)) = A(find(inoK == 2));
    LMnoK(find(inoK == 3)) = (1+g)^(-1/a)*Lu(find(inoK == 3)).*expeM(find(inoK == 3),i).^(-1/a);
    LMnoK(find(inoK == 4)) = eta(find(inoK == 4)).^(1/a).*Lu(find(inoK == 4)).*expeM(find(inoK == 4),i).^(-1/a);
    LMnoK(find(inoK == 5)) = LcM(find(inoK == 5),i) + A(find(inoK == 5));
    
    LiMnoK(:,i) = LMnoK;
        
end
        
   LuM = (Lu*v).*expeM.^(-1/a);

end
