set more 1
global path " "

/********************************************************************

Replicates Table 5 in 
"Contracting under Uncertainty: Groundwater in South India"
Xavier Gine & Hanan Jacoby

(Also Tables C1 & C2 in online Appendix)

********************************************************************/



use "$path\\QE replication\data\Table5.dta" 

des T P CV m_end m_start w_pipe HP ldepth anyrecharge p_scolor p_stype p_sal lpa lta fcaste educ r_age r_nadj lma ratio_wet


/********************** Table 5 ********************/

preserve

***** Full sample
keep if T==1

** normalize by sd
su CV
replace CV=CV/r(sd)

logit P CV m_end m_start w_pipe HP ldepth anyrecharge
local p = e(r2_p)
margins, dydx(CV) post
outreg2  using margeff_v3.xls, replace  adds(r2_p ,`p') addtext(well controls, YES, plot controls, NO, well-owner/adjacency controls, NO, mandal dummies, NO) 


logit P CV m_end m_start w_pipe HP ldepth anyrecharge i.p_scolor i.p_sal i.p_stype lpa
local p = e(r2_p)

margins, dydx(CV)  post
outreg2  using margeff_v3.xls, adds(r2_p ,`p') addtext(well controls, YES, plot controls, YES, well-owner/adjacency controls, NO, mandal dummies, NO) 

logit P CV m_end m_start w_pipe HP ldepth anyrecharge i.p_scolor i.p_stype i.p_sal lpa lta i.fcaste i.educ r_age r_nadj lma 
local p = e(r2_p)

margins, dydx(CV)  post

outreg2  using margeff_v3.xls,  adds(r2_p ,`p') addtext(well controls, YES, plot controls, YES, well-owner/adjacency controls, YES, mandal dummies, NO) 


logit P CV m_end m_start w_pipe HP ldepth anyrecharge i.p_scolor i.p_stype i.p_sal lpa lta i.fcaste i.educ r_age r_nadj lma i.mm
local p = e(r2_p)

margins, dydx(CV)  post

outreg2  using margeff_v3.xls,  adds(r2_p ,`p') addtext(well controls, YES, plot controls, YES, well-owner/adjacency controls, YES, mandal dummies, YES) 
restore

preserve

***** Estimation sample

keep if T==1
keep if sample=="Estimation sample"
su CV
replace CV=CV/r(sd)

logit P CV m_end m_start w_pipe HP ldepth anyrecharge
local p = e(r2_p)
margins, dydx(CV) post
outreg2  using margeff_v3.xls,  adds(r2_p ,`p') addtext(well controls, YES, plot controls, NO, well-owner/adjacency controls, NO, mandal dummies, NO) 


logit P CV m_end m_start w_pipe HP ldepth anyrecharge i.p_scolor i.p_stype i.p_sal lpa
local p = e(r2_p)

margins, dydx(CV)  post
outreg2  using margeff_v3.xls, adds(r2_p ,`p') addtext(well controls, YES, plot controls, YES, well-owner/adjacency controls, NO, mandal dummies, NO) 

logit P CV m_end m_start w_pipe HP ldepth anyrecharge i.p_scolor i.p_stype i.p_sal lpa lta i.fcaste i.educ r_age r_nadj lma 
local p = e(r2_p)

margins, dydx(CV)  post

outreg2  using margeff_v3.xls,  adds(r2_p ,`p') addtext(well controls, YES, plot controls, YES, well-owner/adjacency controls, YES, mandal dummies, NO) 


logit P CV m_end m_start w_pipe HP ldepth anyrecharge i.p_scolor i.p_stype i.p_sal lpa lta i.fcaste i.educ r_age r_nadj lma i.mm
local p = e(r2_p)

margins, dydx(CV)  post

outreg2  using margeff_v3.xls,  adds(r2_p ,`p') addtext(well controls, YES, plot controls, YES, well-owner/adjacency controls, YES, mandal dummies, YES) 

restore



/********************** Table C2 ********************/

preserve
***** Full sample

keep if T==1

su CV
replace CV=CV/r(sd)

logit P CV m_end m_start w_pipe HP ldepth anyrecharge ratio_wet
local p = e(r2_p)
margins, dydx(CV ratio_wet) post

outreg2  using margeff_v4.xls, replace  adds(r2_p ,`p') addtext(well controls, YES, plot controls, NO, well-owner/adjacency controls, NO, mandal dummies, NO) 


logit P CV m_end m_start w_pipe HP ldepth anyrecharge i.p_scolor i.p_sal i.p_stype lpa ratio_wet
local p = e(r2_p)

margins, dydx(CV ratio_wet)  post
outreg2  using margeff_v4.xls, adds(r2_p ,`p') addtext(well controls, YES, plot controls, YES, well-owner/adjacency controls, NO, mandal dummies, NO) 

logit P CV m_end m_start w_pipe HP ldepth anyrecharge i.p_scolor i.p_stype i.p_sal lpa lta i.fcaste i.educ r_age r_nadj lma ratio_wet
local p = e(r2_p)

margins, dydx(CV ratio_wet)  post

outreg2  using margeff_v4.xls,  adds(r2_p ,`p') addtext(well controls, YES, plot controls, YES, well-owner/adjacency controls, YES, mandal dummies, NO) 


logit P CV m_end m_start w_pipe HP ldepth anyrecharge i.p_scolor i.p_stype i.p_sal lpa lta i.fcaste i.educ r_age r_nadj lma ratio_wet i.mm
local p = e(r2_p)

margins, dydx(CV ratio_wet)  post

outreg2  using margeff_v4.xls,  adds(r2_p ,`p') addtext(well controls, YES, plot controls, YES, well-owner/adjacency controls, YES, mandal dummies, YES) 
restore

***** Estimation sample

preserve
keep if T==1
keep if sample=="Estimation sample"
su CV
replace CV=CV/r(sd)

logit P CV m_end m_start w_pipe HP ldepth anyrecharge ratio_wet
local p = e(r2_p)
margins, dydx(CV ratio_wet) post
outreg2  using margeff_v4.xls,  adds(r2_p ,`p') addtext(well controls, YES, plot controls, NO, well-owner/adjacency controls, NO, mandal dummies, NO) 


logit P CV m_end m_start w_pipe HP ldepth anyrecharge i.p_scolor i.p_stype i.p_sal lpa ratio_wet
local p = e(r2_p)

margins, dydx(CV ratio_wet)  post
outreg2  using margeff_v4.xls, adds(r2_p ,`p') addtext(well controls, YES, plot controls, YES, well-owner/adjacency controls, NO, mandal dummies, NO) 

logit P CV m_end m_start w_pipe HP ldepth anyrecharge i.p_scolor i.p_stype i.p_sal lpa lta i.fcaste i.educ r_age r_nadj lma ratio_wet
local p = e(r2_p)

margins, dydx(CV ratio_wet)  post

outreg2  using margeff_v4.xls,  adds(r2_p ,`p') addtext(well controls, YES, plot controls, YES, well-owner/adjacency controls, YES, mandal dummies, NO) 


logit P CV m_end m_start w_pipe HP ldepth anyrecharge i.p_scolor i.p_stype i.p_sal lpa lta i.fcaste i.educ r_age r_nadj lma ratio_wet i.mm
local p = e(r2_p)

margins, dydx(CV ratio_wet)  post

outreg2  using margeff_v4.xls,  adds(r2_p ,`p') addtext(well controls, YES, plot controls, YES, well-owner/adjacency controls, YES, mandal dummies, YES) 

 restore



******************************************************************************************
/** Table C2: GW Transfer probability 
******************************************************************************************/

gen GWT = 1 - NT

preserve
su CV
replace CV=CV/r(sd)


logit GWT CV m_end m_start w_pipe HP ldepth anyrecharge
local p = e(r2_p)
margins, dydx(CV) post
outreg2  using margeff_v3_GWT.xls, replace  adds(r2_p ,`p') addtext(well controls, YES, plot controls, NO, well-owner/adjacency controls, NO, mandal dummies, NO) 


logit GWT CV m_end m_start w_pipe HP ldepth anyrecharge i.p_scolor i.p_stype i.p_sal lpa
local p = e(r2_p)

margins, dydx(CV)  post
outreg2  using margeff_v3_GWT.xls, adds(r2_p ,`p') addtext(well controls, YES, plot controls, YES, well-owner/adjacency controls, NO, mandal dummies, NO) 

logit GWT CV m_end m_start w_pipe HP ldepth anyrecharge i.p_scolor i.p_stype i.p_sal lpa lta i.fcaste i.educ r_age r_nadj lma 
local p = e(r2_p)

margins, dydx(CV)  post

outreg2  using margeff_v3_GWT.xls,  adds(r2_p ,`p') addtext(well controls, YES, plot controls, YES, well-owner/adjacency controls, YES, mandal dummies, NO) 


logit GWT CV m_end m_start w_pipe HP ldepth anyrecharge i.p_scolor i.p_stype i.p_sal lpa lta i.fcaste i.educ r_age r_nadj lma i.mm
local p = e(r2_p)

margins, dydx(CV)  post

outreg2  using margeff_v3_GWT.xls,  adds(r2_p ,`p') addtext(well controls, YES, plot controls, YES, well-owner/adjacency controls, YES, mandal dummies, YES) 
restore

keep if sample=="Estimation sample"

su CV
replace CV=CV/r(sd)


logit GWT CV m_end m_start w_pipe HP ldepth anyrecharge
local p = e(r2_p)
margins, dydx(CV) post
outreg2  using margeff_v3_GWT.xls, adds(r2_p ,`p') addtext(well controls, YES, plot controls, NO, well-owner/adjacency controls, NO, mandal dummies, NO) 


logit GWT CV m_end m_start w_pipe HP ldepth anyrecharge i.p_scolor i.p_stype i.p_sal lpa
local p = e(r2_p)

margins, dydx(CV)  post
outreg2  using margeff_v3_GWT.xls, adds(r2_p ,`p') addtext(well controls, YES, plot controls, YES, well-owner/adjacency controls, NO, mandal dummies, NO) 

logit GWT CV m_end m_start w_pipe HP ldepth anyrecharge i.p_scolor i.p_stype i.p_sal lpa lta i.fcaste i.educ r_age r_nadj lma 
local p = e(r2_p)

margins, dydx(CV)  post

outreg2  using margeff_v3_GWT.xls,  adds(r2_p ,`p') addtext(well controls, YES, plot controls, YES, well-owner/adjacency controls, YES, mandal dummies, NO) 


logit GWT CV m_end m_start w_pipe HP ldepth anyrecharge i.p_scolor i.p_stype i.p_sal lpa lta i.fcaste i.educ r_age r_nadj lma i.mm
local p = e(r2_p)

margins, dydx(CV)  post

outreg2  using margeff_v3_GWT.xls,  adds(r2_p ,`p') addtext(well controls, YES, plot controls, YES, well-owner/adjacency controls, YES, mandal dummies, YES) 
